using Microsoft.AspNetCore.Mvc.Controllers;
using Microsoft.OpenApi.Models;

var builder = WebApplication.CreateBuilder(args);

builder.Services.AddCors();//  CORS
builder.Services.AddControllers();// 
//  Swagger
builder.Services.AddSwaggerGen(option =>
{
    option.SwaggerDoc("v1", new OpenApiInfo { Title = " API", Version = "1.0.0" });
    option.TagActionsBy(api =>
    {
        if (api.GroupName != null)
        {
            return new[] { api.GroupName };
        }
        var controllerActionDiscriotor = api.ActionDescriptor as ControllerActionDescriptor;
        if (controllerActionDiscriotor != null)
        {
            return new[] { controllerActionDiscriotor.ControllerName };
        }
        throw new InvalidOperationException("Unable to determine tag for endpoint.");//      .
    });
    option.DocInclusionPredicate((name, api) => true);
});

var app = builder.Build();

//    
app.MapControllerRoute(
    name: "default",
    pattern: "{controller=Home}/{action=Index}/{id?}");

app.UseCors(builder => builder.AllowAnyOrigin()); // CORS

//       JSON    Swagger
app.UseSwagger();
app.UseSwaggerUI(options =>
{
    options.SwaggerEndpoint("./v1/swagger.json", "1.0.0"); //    
});

app.Run();
